@@ -1,7 +1,7 @@
 use std::fmt;
 
 #[derive(Debug)]
-pub struct Error(jemalloc_ctl::Error);
+pub struct Error(tikv_jemalloc_ctl::Error);
 
 impl std::error::Error for Error {}
 
@@ -12,9 +12,9 @@ impl fmt::Display for Error {
 	}
 }
 
-impl From<jemalloc_ctl::Error> for Error {
+impl From<tikv_jemalloc_ctl::Error> for Error {
 	#[inline]
-	fn from(other: jemalloc_ctl::Error) -> Self {
+	fn from(other: tikv_jemalloc_ctl::Error) -> Self {
 		Self(other)
 	}
 }
